@@ -10,11 +10,10 @@
 #ifndef _BONOBO_CONTROL_INTERNAL_H_
 #define _BONOBO_CONTROL_INTERNAL_H_
 
-#undef DEBUG_CONTROL
-
 #include <bonobo/bonobo-plug.h>
 #include <bonobo/bonobo-socket.h>
 #include <bonobo/bonobo-control.h>
+#include <bonobo/bonobo-ui-private.h>
 #include <bonobo/bonobo-control-frame.h>
 
 void     bonobo_control_add_listener            (CORBA_Object        object,
@@ -33,10 +32,6 @@ void     bonobo_control_frame_set_inproc_widget (BonoboControlFrame *frame,
 						 BonoboPlug         *bonobo_plug,
 						 GtkWidget          *control_widget);
 
-
-void                bonobo_control_notify_plug_died (BonoboControl      *control,
-						     gboolean            inproc_parent_died);
-
 BonoboSocket       *bonobo_control_frame_get_socket (BonoboControlFrame *frame);
 BonoboControlFrame *bonobo_socket_get_control_frame (BonoboSocket       *socket);
 void                bonobo_control_frame_set_socket (BonoboControlFrame *frame,
@@ -52,16 +47,4 @@ void                bonobo_plug_set_control         (BonoboPlug         *plug,
 						     BonoboControl      *control);
 gboolean            bonobo_socket_disposed          (BonoboSocket       *socket);
 
-#ifndef   DEBUG_CONTROL
-
-static inline void dprintf (const char *format, ...) { };
-
-#else  /* DEBUG_CONTROL */
-
-#include <stdio.h>
-
-#define dprintf(format...) fprintf(stderr, format)
-
-#endif /* DEBUG_CONTROL */
-
 #endif /* _BONOBO_CONTROL_INTERNAL_H_ */
