@@ -16,9 +16,15 @@
 #include <bonobo/bonobo-ui-node.h>
 #include <bonobo/bonobo-ui-engine.h>
 #include <bonobo/bonobo-ui-node-private.h>
+#include <bonobo/bonobo-ui-toolbar-control-item.h>
 
+/* To debug plug/socket/control render issues */
+#undef DEBUG_CONTROL
+
+/* To dump lots of sequence information */
 #undef DEBUG_UI
 
+void       bonobo_ui_gconf_leaks_refs     (void);
 void       bonobo_ui_preferences_shutdown (void);
 void       bonobo_ui_image_set_pixbuf     (GtkImage       *image,
 					   GdkPixbuf      *pixbuf);
@@ -26,6 +32,9 @@ GdkPixbuf *bonobo_ui_util_xml_get_pixbuf  (GtkWidget      *widget,
 					   BonoboUINode   *node,
 					   GtkIconSize     icon_size);
 void       bonobo_ui_engine_dispose       (BonoboUIEngine *engine);
+void       bonobo_ui_toolbar_control_item_set_sensitive
+                                          (BonoboUIToolbarControlItem *item,
+					   gboolean                    sensitive);
 
 #ifndef   DEBUG_UI
 
@@ -37,7 +46,7 @@ static inline void dprintf (const char *format, ...) { };
 
 #define dprintf(format...) fprintf(stderr, format)
 
-#endif /* DEBUG_CONTROL */
+#endif /* DEBUG_UI */
 
 #endif /* _BONOBO_UI_PRIVATE_H_ */
 
